@@ -11,7 +11,7 @@ RSpec.describe "Articles management", type: :request, order: :defined do
     it "does not create a version" do
       expect(PaperTrail.request).to be_enabled
       expect {
-        post articles_path, params_wrapper(valid_params)
+        post articles_path, params: valid_params
       }.not_to change(PaperTrail::Version, :count)
     end
   end
@@ -22,7 +22,7 @@ RSpec.describe "Articles management", type: :request, order: :defined do
     context "`current_user` method returns a `String`" do
       it "sets that value as the `whodunnit`" do
         expect {
-          post articles_path, params_wrapper(valid_params)
+          post articles_path, params: valid_params
         }.to change(PaperTrail::Version, :count).by(1)
         expect(article.title).to eq("Doh")
         expect(article.versions.last.whodunnit).to eq("foobar")
